summaryrefslogtreecommitdiff
path: root/Command/Reinject.hs
diff options
context:
space:
mode:
Diffstat (limited to 'Command/Reinject.hs')
-rw-r--r--Command/Reinject.hs6
1 files changed, 4 insertions, 2 deletions
diff --git a/Command/Reinject.hs b/Command/Reinject.hs
index 2c785feb6..de7f6eb3d 100644
--- a/Command/Reinject.hs
+++ b/Command/Reinject.hs
@@ -50,11 +50,13 @@ perform src dest key = do
)
where
-- the file might be on a different filesystem,
- -- so mv is used rather than simply calling
+ -- so moveFile is used rather than simply calling
-- moveToObjectDir; disk space is also
-- checked this way.
move = getViaTmp key $ \tmp ->
- liftIO $ boolSystem "mv" [File src, File tmp]
+ liftIO $ catchBoolIO $ do
+ moveFile src tmp
+ return True
reject = const $ return "wrong file?"
cleanup :: Key -> CommandCleanup